# Actions

Render functions control the data that is pushed from the server to the client. Anything
that is sent from a client to a server is considered an action. Actions are
internally implemented as POST requests that are handled in Javascript, but once built
on the frontend should be fully transparent to you.

---

## Passthrough

::: mountaineer.actions.passthrough_dec.passthrough

---

## Sideeffect

::: mountaineer.actions.sideeffect_dec.sideeffect
